/***************************************************************************
                          rfileplt.h  -  description
                             -------------------
    begin                : Mon Sep 27 1999
    copyright            : (C) 1999 by Andreas Mustun
    email                : andrew@ribbonsoft.com
 ***************************************************************************/

/****************************************************************************
** rfileplt.h 1998/10/08 A. Mustun RibbonSoft 
**
** Copyright (C) 1998 RibbonSoft.  All rights reserved.
**
*****************************************************************************/

#ifndef RFILEPLT_H
#define RFILEPLT_H

#include "rfilebase.h"

#include "rprgdef.h"

class RGraphic;

class RFilePlt : public RFileBase
{
public:
  RFilePlt(const QString& _name, RGraphic* _graphic);
  ~RFilePlt();

  bool load(bool add=false);
  bool readFromBuffer(bool add=false);
    
private:
  RGraphic* graphic;
  int       numElements;
  
};


#endif

// EOF


